Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(837)

Unified Diff: ui/login/account_picker/user_pod_row.js

Issue 960403003: Rename for js pod description to LegacySupervisedUser finished. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/login/account_picker/user_pod_row.js
diff --git a/ui/login/account_picker/user_pod_row.js b/ui/login/account_picker/user_pod_row.js
index ba3c0365ccefde5c65c18ad7b0f91c201138ec83..f52b7a1904e1ac5bb555f6f2cce2ae9c9e8275c1 100644
--- a/ui/login/account_picker/user_pod_row.js
+++ b/ui/login/account_picker/user_pod_row.js
@@ -1026,7 +1026,9 @@ cr.define('login', function() {
loadTimeData.getStringF('ownerUserPattern', this.user_.displayName) :
this.user_.displayName;
this.actionBoxMenuTitleEmailElement.textContent = this.user_.emailAddress;
- this.actionBoxMenuTitleEmailElement.hidden = this.user_.supervisedUser;
+
+ this.actionBoxMenuTitleEmailElement.hidden =
+ this.user_.legacySupervisedUser;
this.actionBoxMenuCommandElement.textContent =
loadTimeData.getString('removeUser');
@@ -1265,7 +1267,7 @@ cr.define('login', function() {
},
showSupervisedUserSigninWarning: function() {
// Supervised user token has been invalidated.
// Make sure that pod is focused i.e. "Sign in" button is seen.
this.parentNode.focusPod(this);
@@ -1299,7 +1301,7 @@ cr.define('login', function() {
* Shows signin UI for this user.
*/
showSigninUI: function() {
- if (this.user.supervisedUser && !this.user.isDesktopUser) {
+ if (this.user.legacySupervisedUser && !this.user.isDesktopUser) {
this.showSupervisedUserSigninWarning();
} else {
// Special case for multi-profiles sign in. We show users even if they
@@ -1265,7 +1267,7 @@ cr.define('login', function() {
},
showSupervisedUserSigninWarning: function() {
- // Supervised user token has been invalidated.
+ // Legacy supervised user token has been invalidated.
// Make sure that pod is focused i.e. "Sign in" button is seen.
this.parentNode.focusPod(this);
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698